==> giada_1.2.1.orig.tar.xz: giada-1.2.1/src/core/model/loadState.h <==
/* -----------------------------------------------------------------------------
 *
 * Giada - Your Hardcore Loopmachine
 *
 * -----------------------------------------------------------------------------
 *
 * Copyright (C) 2010-2025 Giovanni A. Zuliani | Monocasual Laboratories
 *
 * This file is part of Giada - Your Hardcore Loopmachine.
 *
 * Giada - Your Hardcore Loopmachine is free software: you can
 * redistribute it and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation, either
 * version 3 of the License, or (at your option) any later version.
 *
 * Giada - Your Hardcore Loopmachine is distributed in the hope that it
 * will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Giada - Your Hardcore Loopmachine. If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * -------------------------------------------------------------------------- */

#ifndef G_MODEL_LOADSTATE_H
#define G_MODEL_LOADSTATE_H

#include "core/patch.h"

namespace giada::m::model
{
/* LoadState
Contains information about the model state after a patch has been loaded. */

struct LoadState
{
	bool isGood() const;

	Patch                    patch;
	std::vector<std::string> missingWaves   = {};
	std::vector<std::string> missingPlugins = {};
};
} // namespace giada::m::model

#endif

==> giada_1.4.0.orig.tar.xz: giada-1.4.0/src/core/model/loadState.h <==
/* -----------------------------------------------------------------------------
 *
 * Giada - Your Hardcore Loopmachine
 *
 * -----------------------------------------------------------------------------
 *
 * Copyright (C) 2010-2025 Giovanni A. Zuliani | Monocasual Laboratories
 *
 * This file is part of Giada - Your Hardcore Loopmachine.
 *
 * Giada - Your Hardcore Loopmachine is free software: you can
 * redistribute it and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation, either
 * version 3 of the License, or (at your option) any later version.
 *
 * Giada - Your Hardcore Loopmachine is distributed in the hope that it
 * will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Giada - Your Hardcore Loopmachine. If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * -------------------------------------------------------------------------- */

#ifndef G_MODEL_LOADSTATE_H
#define G_MODEL_LOADSTATE_H

#include "src/core/patch.h"
#include <unordered_set>

namespace giada::m::model
{
/* LoadState
Contains information about the model state after a patch has been loaded. */

struct LoadState
{
	bool isGood() const;

	Patch                           patch;
	std::vector<std::string>        missingWaves   = {};
	std::unordered_set<std::string> missingPlugins = {};
};
} // namespace giada::m::model

#endif
